Class: Google::Apis::MemcacheV1beta2::GoogleCloudMemcacheV1beta2MaintenancePolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb

Overview

Maintenance policy per instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudMemcacheV1beta2MaintenancePolicy

Returns a new instance of GoogleCloudMemcacheV1beta2MaintenancePolicy.



328
329
330
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the policy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


308
309
310
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 308

def create_time
  @create_time
end

#descriptionString

Description of what this policy is for. Create/Update methods return INVALID_ARGUMENT if the length is greater than 512. Corresponds to the JSON property description

Returns:

  • (String)


314
315
316
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 314

def description
  @description
end

#update_timeString

Output only. The time when the policy was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


319
320
321
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 319

def update_time
  @update_time
end

#weekly_maintenance_windowArray<Google::Apis::MemcacheV1beta2::WeeklyMaintenanceWindow>

Required. Maintenance window that is applied to resources covered by this policy. Minimum 1. For the current version, the maximum number of weekly_maintenance_windows is expected to be one. Corresponds to the JSON property weeklyMaintenanceWindow



326
327
328
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 326

def weekly_maintenance_window
  @weekly_maintenance_window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



333
334
335
336
337
338
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 333

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @update_time = args[:update_time] if args.key?(:update_time)
  @weekly_maintenance_window = args[:weekly_maintenance_window] if args.key?(:weekly_maintenance_window)
end