Class: Google::Apis::MemcacheV1beta2::GoogleCloudMemcacheV1beta2OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1beta2::GoogleCloudMemcacheV1beta2OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb
Overview
Represents the metadata of a long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudMemcacheV1beta2OperationMetadata
constructor
A new instance of GoogleCloudMemcacheV1beta2OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudMemcacheV1beta2OperationMetadata
Returns a new instance of GoogleCloudMemcacheV1beta2OperationMetadata.
384 385 386 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
348 349 350 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 348 def api_version @api_version end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property cancelRequested
356 357 358 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 356 def cancel_requested @cancel_requested end |
#create_time ⇒ String
Output only. Time when the operation was created.
Corresponds to the JSON property createTime
362 363 364 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 362 def create_time @create_time end |
#end_time ⇒ String
Output only. Time when the operation finished running.
Corresponds to the JSON property endTime
367 368 369 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 367 def end_time @end_time end |
#status_detail ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusDetail
372 373 374 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 372 def status_detail @status_detail end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
377 378 379 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 377 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
382 383 384 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 382 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
389 390 391 392 393 394 395 396 397 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 389 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @status_detail = args[:status_detail] if args.key?(:status_detail) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |