Class: Google::Apis::MemcacheV1beta2::GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1beta2::GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb
Overview
SloEligibility is a tuple containing eligibility value: true if an instance is eligible for SLO calculation or false if it should be excluded from all SLO- related calculations along with a user-defined reason.
Instance Attribute Summary collapse
-
#eligible ⇒ Boolean
(also: #eligible?)
Whether an instance is eligible or ineligible.
-
#reason ⇒ String
User-defined reason for the current value of instance eligibility.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility
constructor
A new instance of GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility
Returns a new instance of GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility.
830 831 832 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eligible ⇒ Boolean Also known as: eligible?
Whether an instance is eligible or ineligible.
Corresponds to the JSON property eligible
821 822 823 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 821 def eligible @eligible end |
#reason ⇒ String
User-defined reason for the current value of instance eligibility. Usually,
this can be directly mapped to the internal state. An empty reason is allowed.
Corresponds to the JSON property reason
828 829 830 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 828 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
835 836 837 838 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 835 def update!(**args) @eligible = args[:eligible] if args.key?(:eligible) @reason = args[:reason] if args.key?(:reason) end |