Class: Google::Apis::MemcacheV1beta2::MaintenanceSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb

Overview

Upcoming maintenance schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceSchedule

Returns a new instance of MaintenanceSchedule.



1338
1339
1340
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. The end time of any upcoming scheduled maintenance for this instance. Corresponds to the JSON property endTime

Returns:

  • (String)


1324
1325
1326
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1324

def end_time
  @end_time
end

#schedule_deadline_timeString

Output only. The deadline that the maintenance schedule start time can not go beyond, including reschedule. Corresponds to the JSON property scheduleDeadlineTime

Returns:

  • (String)


1330
1331
1332
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1330

def schedule_deadline_time
  @schedule_deadline_time
end

#start_timeString

Output only. The start time of any upcoming scheduled maintenance for this instance. Corresponds to the JSON property startTime

Returns:

  • (String)


1336
1337
1338
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1336

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1343
1344
1345
1346
1347
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1343

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @schedule_deadline_time = args[:schedule_deadline_time] if args.key?(:schedule_deadline_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end