Class: Google::Apis::MemcacheV1beta2::MemcacheParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MemcacheParameters

Returns a new instance of MemcacheParameters.



1393
1394
1395
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. The unique ID associated with this set of parameters. Users can use this id to determine if the parameters associated with the instance differ from the parameters associated with the nodes. A discrepancy between parameter ids can inform users that they may need to take action to apply parameters on nodes. Corresponds to the JSON property id

Returns:

  • (String)


1386
1387
1388
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1386

def id
  @id
end

#paramsHash<String,String>

User defined set of parameters to use in the memcached process. Corresponds to the JSON property params

Returns:

  • (Hash<String,String>)


1391
1392
1393
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1391

def params
  @params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1398
1399
1400
1401
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1398

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @params = args[:params] if args.key?(:params)
end