Class: Google::Apis::MemcacheV1beta2::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1beta2::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::MemcacheV1beta2::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
1670 1671 1672 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
1656 1657 1658 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1656 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
1661 1662 1663 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1661 def duration @duration end |
#start_time ⇒ Google::Apis::MemcacheV1beta2::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
1668 1669 1670 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1668 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1675 1676 1677 1678 1679 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1675 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |