Class: Google::Apis::MemcacheV1beta2::TimeOfDay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb

Overview

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeOfDay

Returns a new instance of TimeOfDay.



1828
1829
1830
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hoursFixnum

Hours of a day in 24 hour format. Must be greater than or equal to 0 and typically must be less than or equal to 23. An API may choose to allow the value "24:00:00" for scenarios like business closing time. Corresponds to the JSON property hours

Returns:

  • (Fixnum)


1807
1808
1809
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1807

def hours
  @hours
end

#minutesFixnum

Minutes of an hour. Must be greater than or equal to 0 and less than or equal to 59. Corresponds to the JSON property minutes

Returns:

  • (Fixnum)


1813
1814
1815
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1813

def minutes
  @minutes
end

#nanosFixnum

Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and less than or equal to 999,999,999. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


1819
1820
1821
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1819

def nanos
  @nanos
end

#secondsFixnum

Seconds of a minute. Must be greater than or equal to 0 and typically must be less than or equal to 59. An API may allow the value 60 if it allows leap- seconds. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


1826
1827
1828
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1826

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1833
1834
1835
1836
1837
1838
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1833

def update!(**args)
  @hours = args[:hours] if args.key?(:hours)
  @minutes = args[:minutes] if args.key?(:minutes)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end