Class: Google::Apis::MemcacheV1beta2::WeeklyMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb

Overview

Time window specified for weekly operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeeklyMaintenanceWindow

Returns a new instance of WeeklyMaintenanceWindow.



1939
1940
1941
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1939

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Required. Allows to define schedule that runs specified day of the week. Corresponds to the JSON property day

Returns:

  • (String)


1925
1926
1927
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1925

def day
  @day
end

#durationString

Required. Duration of the time window. Corresponds to the JSON property duration

Returns:

  • (String)


1930
1931
1932
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1930

def duration
  @duration
end

#start_timeGoogle::Apis::MemcacheV1beta2::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



1937
1938
1939
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1937

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1944
1945
1946
1947
1948
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1944

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end