Class: Google::Apis::MemcacheV1beta2::Instance
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1beta2::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb
Overview
A Memorystore for Memcached instance
Instance Attribute Summary collapse
-
#authorized_network ⇒ String
The full name of the Google Compute Engine network to which the instance is connected.
-
#available_maintenance_versions ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#discovery_endpoint ⇒ String
Output only.
-
#display_name ⇒ String
User provided name for the instance, which is only used for display purposes.
-
#effective_maintenance_version ⇒ String
Output only.
-
#instance_messages ⇒ Array<Google::Apis::MemcacheV1beta2::InstanceMessage>
List of messages that describe the current state of the Memcached instance.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user-provided metadata.
-
#maintenance_policy ⇒ Google::Apis::MemcacheV1beta2::GoogleCloudMemcacheV1beta2MaintenancePolicy
Maintenance policy per instance.
-
#maintenance_schedule ⇒ Google::Apis::MemcacheV1beta2::MaintenanceSchedule
Upcoming maintenance schedule.
-
#maintenance_version ⇒ String
Optional.
-
#memcache_full_version ⇒ String
Output only.
-
#memcache_nodes ⇒ Array<Google::Apis::MemcacheV1beta2::Node>
Output only.
-
#memcache_version ⇒ String
The major version of Memcached software.
-
#name ⇒ String
Required.
-
#node_config ⇒ Google::Apis::MemcacheV1beta2::NodeConfig
Configuration for a Memcached Node.
-
#node_count ⇒ Fixnum
Required.
-
#parameters ⇒ Google::Apis::MemcacheV1beta2::MemcacheParameters
User defined parameters to apply to the memcached process on each node.
-
#reserved_ip_range_id ⇒ Array<String>
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Optional.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Optional.
-
#state ⇒ String
Output only.
-
#update_available ⇒ Boolean
(also: #update_available?)
Output only.
-
#update_time ⇒ String
Output only.
-
#zones ⇒ Array<String>
Zones in which Memcached nodes should be provisioned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
1033 1034 1035 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorized_network ⇒ String
The full name of the Google Compute Engine network to which the instance is connected. If left unspecified, the
default network will be used.
Corresponds to the JSON property authorizedNetwork
887 888 889 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 887 def @authorized_network end |
#available_maintenance_versions ⇒ Array<String>
Output only. The available maintenance versions that can be applied to the
instance.
Corresponds to the JSON property availableMaintenanceVersions
893 894 895 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 893 def available_maintenance_versions @available_maintenance_versions end |
#create_time ⇒ String
Output only. The time the instance was created.
Corresponds to the JSON property createTime
898 899 900 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 898 def create_time @create_time end |
#discovery_endpoint ⇒ String
Output only. Endpoint for the Discovery API.
Corresponds to the JSON property discoveryEndpoint
903 904 905 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 903 def discovery_endpoint @discovery_endpoint end |
#display_name ⇒ String
User provided name for the instance, which is only used for display purposes.
Cannot be more than 80 characters.
Corresponds to the JSON property displayName
909 910 911 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 909 def display_name @display_name end |
#effective_maintenance_version ⇒ String
Output only. The effective maintenance version of the instance.
Corresponds to the JSON property effectiveMaintenanceVersion
914 915 916 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 914 def effective_maintenance_version @effective_maintenance_version end |
#instance_messages ⇒ Array<Google::Apis::MemcacheV1beta2::InstanceMessage>
List of messages that describe the current state of the Memcached instance.
Corresponds to the JSON property instanceMessages
919 920 921 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 919 def @instance_messages end |
#labels ⇒ Hash<String,String>
Resource labels to represent user-provided metadata. Refer to cloud
documentation on labels for more details. https://cloud.google.com/compute/
docs/labeling-resources
Corresponds to the JSON property labels
926 927 928 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 926 def labels @labels end |
#maintenance_policy ⇒ Google::Apis::MemcacheV1beta2::GoogleCloudMemcacheV1beta2MaintenancePolicy
Maintenance policy per instance.
Corresponds to the JSON property maintenancePolicy
931 932 933 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 931 def maintenance_policy @maintenance_policy end |
#maintenance_schedule ⇒ Google::Apis::MemcacheV1beta2::MaintenanceSchedule
Upcoming maintenance schedule.
Corresponds to the JSON property maintenanceSchedule
936 937 938 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 936 def maintenance_schedule @maintenance_schedule end |
#maintenance_version ⇒ String
Optional. Last self service update maintenance version triggered by the
customer. If it is empty, it means that the maintenance version is not set by
the user.
Corresponds to the JSON property maintenanceVersion
943 944 945 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 943 def maintenance_version @maintenance_version end |
#memcache_full_version ⇒ String
Output only. The full version of memcached server running on this instance.
System automatically determines the full memcached version for an instance
based on the input MemcacheVersion. The full version format will be "memcached-
1.5.16".
Corresponds to the JSON property memcacheFullVersion
951 952 953 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 951 def memcache_full_version @memcache_full_version end |
#memcache_nodes ⇒ Array<Google::Apis::MemcacheV1beta2::Node>
Output only. List of Memcached nodes. Refer to Node message for more details.
Corresponds to the JSON property memcacheNodes
956 957 958 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 956 def memcache_nodes @memcache_nodes end |
#memcache_version ⇒ String
The major version of Memcached software. If not provided, latest supported
version will be used. Currently the latest supported major version is
MEMCACHE_1_5. The minor version will be automatically determined by our
system based on the latest supported minor version.
Corresponds to the JSON property memcacheVersion
964 965 966 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 964 def memcache_version @memcache_version end |
#name ⇒ String
Required. Unique name of the resource in this scope including project and
location using the form: projects/project_id/locations/location_id/
instances/instance_id`Note: Memcached instances are managed and addressed
at the regional level solocation_idhere refers to a Google Cloud region;
however, users may choose which zones Memcached nodes should be provisioned in
within an instance. Refer to zones field for more details.
Corresponds to the JSON propertyname`
974 975 976 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 974 def name @name end |
#node_config ⇒ Google::Apis::MemcacheV1beta2::NodeConfig
Configuration for a Memcached Node.
Corresponds to the JSON property nodeConfig
979 980 981 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 979 def node_config @node_config end |
#node_count ⇒ Fixnum
Required. Number of nodes in the Memcached instance.
Corresponds to the JSON property nodeCount
984 985 986 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 984 def node_count @node_count end |
#parameters ⇒ Google::Apis::MemcacheV1beta2::MemcacheParameters
User defined parameters to apply to the memcached process on each node.
Corresponds to the JSON property parameters
989 990 991 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 989 def parameters @parameters end |
#reserved_ip_range_id ⇒ Array<String>
Optional. Contains the id of allocated IP address ranges associated with the
private service access connection for example, "test-default" associated with
IP range 10.0.0.0/29.
Corresponds to the JSON property reservedIpRangeId
996 997 998 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 996 def reserved_ip_range_id @reserved_ip_range_id end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Optional. Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1001 1002 1003 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1001 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Optional. Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1007 1008 1009 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1007 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of this Memcached instance.
Corresponds to the JSON property state
1013 1014 1015 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1013 def state @state end |
#update_available ⇒ Boolean Also known as: update_available?
Output only. Returns true if there is an update waiting to be applied
Corresponds to the JSON property updateAvailable
1018 1019 1020 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1018 def update_available @update_available end |
#update_time ⇒ String
Output only. The time the instance was updated.
Corresponds to the JSON property updateTime
1024 1025 1026 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1024 def update_time @update_time end |
#zones ⇒ Array<String>
Zones in which Memcached nodes should be provisioned. Memcached nodes will be
equally distributed across these zones. If not provided, the service will by
default create nodes in all zones in the region for the instance.
Corresponds to the JSON property zones
1031 1032 1033 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1031 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1038 def update!(**args) @authorized_network = args[:authorized_network] if args.key?(:authorized_network) @available_maintenance_versions = args[:available_maintenance_versions] if args.key?(:available_maintenance_versions) @create_time = args[:create_time] if args.key?(:create_time) @discovery_endpoint = args[:discovery_endpoint] if args.key?(:discovery_endpoint) @display_name = args[:display_name] if args.key?(:display_name) @effective_maintenance_version = args[:effective_maintenance_version] if args.key?(:effective_maintenance_version) @instance_messages = args[:instance_messages] if args.key?(:instance_messages) @labels = args[:labels] if args.key?(:labels) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule) @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version) @memcache_full_version = args[:memcache_full_version] if args.key?(:memcache_full_version) @memcache_nodes = args[:memcache_nodes] if args.key?(:memcache_nodes) @memcache_version = args[:memcache_version] if args.key?(:memcache_version) @name = args[:name] if args.key?(:name) @node_config = args[:node_config] if args.key?(:node_config) @node_count = args[:node_count] if args.key?(:node_count) @parameters = args[:parameters] if args.key?(:parameters) @reserved_ip_range_id = args[:reserved_ip_range_id] if args.key?(:reserved_ip_range_id) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_available = args[:update_available] if args.key?(:update_available) @update_time = args[:update_time] if args.key?(:update_time) @zones = args[:zones] if args.key?(:zones) end |