Class: Google::Apis::MemcacheV1beta2::Node
- Inherits:
-
Object
- Object
- Google::Apis::MemcacheV1beta2::Node
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/memcache_v1beta2/classes.rb,
lib/google/apis/memcache_v1beta2/representations.rb,
lib/google/apis/memcache_v1beta2/representations.rb
Instance Attribute Summary collapse
-
#host ⇒ String
Output only.
-
#memcache_full_version ⇒ String
Output only.
-
#memcache_version ⇒ String
Output only.
-
#node_id ⇒ String
Output only.
-
#parameters ⇒ Google::Apis::MemcacheV1beta2::MemcacheParameters
User defined parameters currently applied to the node.
-
#port ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
-
#update_available ⇒ Boolean
(also: #update_available?)
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Node
constructor
A new instance of Node.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Node
Returns a new instance of Node.
1458 1459 1460 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1458 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Output only. Hostname or IP address of the Memcached node used by the clients
to connect to the Memcached server on this node.
Corresponds to the JSON property host
1412 1413 1414 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1412 def host @host end |
#memcache_full_version ⇒ String
Output only. The full version of memcached server running on this node. e.g. -
memcached-1.5.16
Corresponds to the JSON property memcacheFullVersion
1418 1419 1420 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1418 def memcache_full_version @memcache_full_version end |
#memcache_version ⇒ String
Output only. Major version of memcached server running on this node, e.g.
MEMCACHE_1_5
Corresponds to the JSON property memcacheVersion
1424 1425 1426 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1424 def memcache_version @memcache_version end |
#node_id ⇒ String
Output only. Identifier of the Memcached node. The node id does not include
project or location like the Memcached instance name.
Corresponds to the JSON property nodeId
1430 1431 1432 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1430 def node_id @node_id end |
#parameters ⇒ Google::Apis::MemcacheV1beta2::MemcacheParameters
User defined parameters currently applied to the node.
Corresponds to the JSON property parameters
1435 1436 1437 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1435 def parameters @parameters end |
#port ⇒ Fixnum
Output only. The port number of the Memcached server on this node.
Corresponds to the JSON property port
1440 1441 1442 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1440 def port @port end |
#state ⇒ String
Output only. Current state of the Memcached node.
Corresponds to the JSON property state
1445 1446 1447 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1445 def state @state end |
#update_available ⇒ Boolean Also known as: update_available?
Output only. Returns true if there is an update waiting to be applied
Corresponds to the JSON property updateAvailable
1450 1451 1452 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1450 def update_available @update_available end |
#zone ⇒ String
Output only. Location (GCP Zone) for the Memcached node.
Corresponds to the JSON property zone
1456 1457 1458 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1456 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 |
# File 'lib/google/apis/memcache_v1beta2/classes.rb', line 1463 def update!(**args) @host = args[:host] if args.key?(:host) @memcache_full_version = args[:memcache_full_version] if args.key?(:memcache_full_version) @memcache_version = args[:memcache_version] if args.key?(:memcache_version) @node_id = args[:node_id] if args.key?(:node_id) @parameters = args[:parameters] if args.key?(:parameters) @port = args[:port] if args.key?(:port) @state = args[:state] if args.key?(:state) @update_available = args[:update_available] if args.key?(:update_available) @zone = args[:zone] if args.key?(:zone) end |